A list of personal functionalities used throughout my career.

Each functionality will be short and have a single purpose.

Firstly, I will list each functionality with a one sentence description. Following each functionality will be demonstrated along with an example and output. 

Enjoy.

**Description**:

- split_x_into_n: Splits two variables into a list of n parts from [0, ..., x] 

- count_occurence:


**Examples**:

- **split_x_into_n**:

split(10, 5)

output: [0, 2, ,4, 6, 8, 10]

split(10, 5, include_zero=False)

output: [2, 4, 6, 8, 10]
